/****************************************************************************
** Meta object code from reading C++ file 'tabletareaselectionview.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../wacomtablet-6.7.4/src/kcmodule/tabletareaselectionview.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tabletareaselectionview.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t {};
} // unnamed namespace

template <> constexpr inline auto Wacom::TabletAreaSelectionView::qt_create_metaobjectdata<qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Wacom::TabletAreaSelectionView",
        "signalCalibrateClicked",
        "",
        "signalFullTabletSelection",
        "signalScreenToggle",
        "signalSetScreenProportions",
        "signalTabletAreaSelection",
        "onCalibrateClicked",
        "onForceProportionsClicked",
        "onFullTabletSelected",
        "checked",
        "onScreenToggle",
        "onTabletAreaSelected",
        "onLockProportionsToggled",
        "enabled",
        "onSelectionChanged",
        "onFineTuneValuesChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalCalibrateClicked'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalFullTabletSelection'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalScreenToggle'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalSetScreenProportions'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'signalTabletAreaSelection'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onCalibrateClicked'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onForceProportionsClicked'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFullTabletSelected'
        QtMocHelpers::SlotData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'onScreenToggle'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTabletAreaSelected'
        QtMocHelpers::SlotData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Slot 'onLockProportionsToggled'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'onSelectionChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFineTuneValuesChanged'
        QtMocHelpers::SlotData<void(QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TabletAreaSelectionView, qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Wacom::TabletAreaSelectionView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t>.metaTypes,
    nullptr
} };

void Wacom::TabletAreaSelectionView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TabletAreaSelectionView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalCalibrateClicked(); break;
        case 1: _t->signalFullTabletSelection(); break;
        case 2: _t->signalScreenToggle(); break;
        case 3: _t->signalSetScreenProportions(); break;
        case 4: _t->signalTabletAreaSelection(); break;
        case 5: _t->onCalibrateClicked(); break;
        case 6: _t->onForceProportionsClicked(); break;
        case 7: _t->onFullTabletSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->onScreenToggle(); break;
        case 9: _t->onTabletAreaSelected((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->onLockProportionsToggled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->onSelectionChanged(); break;
        case 12: _t->onFineTuneValuesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TabletAreaSelectionView::*)()>(_a, &TabletAreaSelectionView::signalCalibrateClicked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletAreaSelectionView::*)()>(_a, &TabletAreaSelectionView::signalFullTabletSelection, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletAreaSelectionView::*)()>(_a, &TabletAreaSelectionView::signalScreenToggle, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletAreaSelectionView::*)()>(_a, &TabletAreaSelectionView::signalSetScreenProportions, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TabletAreaSelectionView::*)()>(_a, &TabletAreaSelectionView::signalTabletAreaSelection, 4))
            return;
    }
}

const QMetaObject *Wacom::TabletAreaSelectionView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Wacom::TabletAreaSelectionView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5Wacom23TabletAreaSelectionViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Wacom::TabletAreaSelectionView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 13)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 13)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void Wacom::TabletAreaSelectionView::signalCalibrateClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Wacom::TabletAreaSelectionView::signalFullTabletSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Wacom::TabletAreaSelectionView::signalScreenToggle()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Wacom::TabletAreaSelectionView::signalSetScreenProportions()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Wacom::TabletAreaSelectionView::signalTabletAreaSelection()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
